==> xmedcon_0.15.0%2Bdfsg.orig.tar.xz: xmedcon-0.15.0/source/xreader.h <==
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 * filename: xreader.h                                                     *
 *                                                                         *
 * UTIL C-source: Medical Image Conversion Utility                         *
 *                                                                         *
 * purpose      : xreader.c header file                                    *
 *                                                                         *
 * project      : (X)MedCon by Erik Nolf                                   *
 *                                                                         *
 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* $Id$
 */

/*
   Copyright (C) 1997-2018 by Erik Nolf

   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
   Free Software Foundation; either version 2, or (at your option) any later
   version.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
   Public License for more details.

   You should have received a copy of the GNU General Public License along
   with this program; if not, write to the Free Software Foundation, Inc.,
   59 Place - Suite 330, Boston, MA 02111-1307, USA.  */

#ifndef __XREADER_H__
#define __XREADER_H__

/****************************************************************************
                              D E F I N E S 
****************************************************************************/

int XMdcReadFile(const char *fname);
void XMdcRawReadFinish(guint otype);
void XMdcRawReadInteractive(GtkWidget *fs);
void XMdcRawReadPredef(GtkWidget *fs);
void XMdcRawReadCancel(guint otype);
Int16 XMdcGetImageInfoPixelType(void);
void XMdcGetImageInfoCallbackApply(void);
void XMdcGetImageInfoCallbackCancel(void);
void XMdcGetImageInfo(void);
void XMdcGetHeaderInfoCallbackApply(void);
void XMdcGetHeaderInfo(void);

#endif

==> xmedcon_0.21.2%2Bdfsg.orig.tar.xz: xmedcon-0.21.2/source/xreader.h <==
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 * filename: xreader.h                                                     *
 *                                                                         *
 * UTIL C-source: Medical Image Conversion Utility                         *
 *                                                                         *
 * purpose      : xreader.c header file                                    *
 *                                                                         *
 * project      : (X)MedCon by Erik Nolf                                   *
 *                                                                         *
 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/*
 */

/*
   Copyright (C) 1997-2021 by Erik Nolf

   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
   Free Software Foundation; either version 2, or (at your option) any later
   version.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
   Public License for more details.

   You should have received a copy of the GNU General Public License along
   with this program; if not, write to the Free Software Foundation, Inc.,
   59 Place - Suite 330, Boston, MA 02111-1307, USA.  */

#ifndef __XREADER_H__
#define __XREADER_H__

/****************************************************************************
                              D E F I N E S
****************************************************************************/

int XMdcReadFile(char *fname);
void XMdcRawReadFinish(guint otype);
void XMdcRawReadInteractive(char *fname);
void XMdcRawReadPredef(char *fname);
void XMdcRawReadCancel(guint otype);
Int16 XMdcGetImageInfoPixelType(void);
void XMdcGetImageInfoCallbackApply(void);
void XMdcGetImageInfoCallbackCancel(void);
void XMdcGetImageInfo(void);
void XMdcGetHeaderInfoCallbackApply(void);
void XMdcGetHeaderInfo(void);

#endif
